@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai-app-static
 version: 3.1.4.1
-id: wai-app-static-3.1.4.1-5d5bb24da470126a4cd2d84387cf1b92
-key: waiap_IfgHB6BiYYI6Sh1YHgI9XN
+id: wai-app-static-3.1.4.1-44f6dcf8d731760c41ac34c914e6b5b3
+key: waiap_HTYeeFLF3bR0hkhbg1yQoH
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
 stability: Stable
@@ -24,7 +24,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.4.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.4.1
-hs-libraries: HSwai-app-static-3.1.4.1-IfgHB6BiYYI6Sh1YHgI9XN
+hs-libraries: HSwai-app-static-3.1.4.1-HTYeeFLF3bR0hkhbg1yQoH
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
@@ -35,11 +35,11 @@ depends:
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
-    cryptohash-conduit-0.1.1-9de27027fde4769c987c6d79fca939a3
+    cryptohash-conduit-0.1.1-6b607828fd72a263de0a99a243d6077b
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-date-0.0.6.1-fcef85ec3f020c9d6f587d45aa9f4919
+    http-date-0.0.6.1-ba351a4841239284d88745a26c501ccf
     http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
@@ -51,8 +51,8 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
-    wai-extra-3.0.13.1-22d19709bfcccb29f4594bf354c81852
-    warp-3.2.3-fdc49a5718602b1caa75db5ed6223617
+    wai-extra-3.0.14.1-66e8055b51d984feb43fefdbcd17f927
+    warp-3.2.3-b193a405602f21fe67837dcb996939ee
     zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
 haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
 haddock-html: /usr/share/doc/haskell-wai-app-static/html
